
# Reddit MCP Server

An MCP Server for the Reddit API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Reddit API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| create_post | Create a new post in a specified subreddit. |
| delete_content | Delete a Reddit post or comment. |
| edit_content | Edit the text content of a Reddit post or comment. |
| get_comment_by_id | Retrieve a specific Reddit comment by its full ID (t1_commentid). |
| get_post_flairs | Retrieve the list of available post flairs for a specific subreddit. |
| get_subreddit_posts | Get the top posts from a specified subreddit over a given timeframe. |
| post_comment | Post a comment to a Reddit post or another comment. |
| search_subreddits | Search for subreddits matching a query string. |
| validate | Function for validate |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Reddit app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
